@@ -1018,7 +1018,7 @@ sub _LALR {
 
 1;
 
-=head1 Parse::Eyapp::Lalr
+=head1 NAME
  
 Parse::Eyapp::Lalr - Method to generate the LALR parsing tables
  
@@ -1030,6 +1030,12 @@ No documentation here. To learn about Parse::Eyapp::Lalr see:
 
 =item * L<Parse::Eyapp>,
 
+=item * L<eyapptut>
+
+=item * The pdf files in L<http://nereida.deioc.ull.es/~pl/perlexamples/Eyapp.pdf> and  
+L<http://nereida.deioc.ull.es/~pl/perlexamples/eyapptut.pdf>.
+
+
 =item * L<http://nereida.deioc.ull.es/~pl/perlexamples/section_eyappts.html> (Spanish),
 
 =item * L<eyapp>,
